@@ -1,6 +1,6 @@
 package Bio::Das::Segment;
 
-# $Id: Segment.pm,v 1.16 2005/08/24 16:10:11 lstein Exp $
+# $Id: Segment.pm,v 1.17 2007/09/06 10:20:42 lstein Exp $
 use strict;
 use Bio::Root::Root;
 use Bio::Das::SegmentI;
@@ -62,6 +62,10 @@ sub features {
 			-segment=> [$self]);
 }
 
+sub source_tag {
+  return shift()->dsn;
+}
+
 sub autotypes {
   my $self = shift;
   my $d  = $self->{autotypes};
